@@ -13,12 +13,9 @@ from .dom import (
     DomSnapshot,
 )
 
-from .llm_browser.dom_filter_config import DomFilterConfig
-
 from .llm import (
     Context,
     Block,
-    Tokenizer,
     LLM,
 )
 
@@ -28,33 +25,23 @@ __version__ = "0.1.0"
 
 __all__ = [
     # Manager
-    'Webtask',
-
+    "Webtask",
     # Agent
-    'Agent',
-
+    "Agent",
     # DOM types
-    'DomNode',
-    'DomNodeData',
-    'Text',
-    'BoundingBox',
-
+    "DomNode",
+    "DomNodeData",
+    "Text",
+    "BoundingBox",
     # Parsers
-    'parse_html',
-    'parse_cdp',
-
+    "parse_html",
+    "parse_cdp",
     # Snapshot
-    'DomSnapshot',
-
-    # Config
-    'DomFilterConfig',
-
+    "DomSnapshot",
     # LLM
-    'Context',
-    'Block',
-    'Tokenizer',
-    'LLM',
-
+    "Context",
+    "Block",
+    "LLM",
     # Media
-    'Image',
+    "Image",
 ]
