@@ -1,10 +1,9 @@
 """Webtask - main manager class for web automation."""
 
 from typing import Optional
-from .browser import Browser, Session
+from .browser import Browser
 from .llm import LLM
 from .agent import Agent
-from .llm_browser.dom_filter_config import DomFilterConfig
 
 
 class Webtask:
@@ -26,8 +25,7 @@ class Webtask:
             from .integrations.browser.playwright import PlaywrightBrowser
 
             self.browser = await PlaywrightBrowser.create_browser(
-                headless=self.headless,
-                browser_type=self.browser_type
+                headless=self.headless, browser_type=self.browser_type
             )
 
         return self.browser
@@ -37,17 +35,17 @@ class Webtask:
         llm: LLM,
         cookies=None,
         action_delay: float = 1.0,
-        dom_filter_config: Optional[DomFilterConfig] = None,
         use_screenshot: bool = True,
+        selector_llm: Optional[LLM] = None,
     ) -> Agent:
         """Create agent with new session. Launches browser on first call.
 
         Args:
-            llm: LLM instance for reasoning
+            llm: LLM instance for reasoning (task planning, completion checking)
             cookies: Optional cookies for the session
             action_delay: Delay in seconds after actions (default: 1.0)
-            dom_filter_config: Configuration for DOM filtering
             use_screenshot: Use screenshots with bounding boxes in LLM context (default: True)
+            selector_llm: Optional separate LLM for element selection (defaults to main llm)
         """
         browser = await self._ensure_browser()
         session = await browser.create_session(cookies=cookies)
@@ -55,8 +53,8 @@ class Webtask:
             llm,
             session=session,
             action_delay=action_delay,
-            dom_filter_config=dom_filter_config,
             use_screenshot=use_screenshot,
+            selector_llm=selector_llm,
         )
 
         return agent
